# AustinFairylandRepository

> @File: README.md  
> @Editor: PyCharm  
> @Author: [Austin (From Chengdu.China)](https://fairy.host)  
> @HomePage: [AustinFairyland](https://github.com/AustinFairyland)  
> @OperatingSystem: Windows 11 Professional Workstation 23H2 Canary Channel  
> @CreatedTime: 2024-01-07

[![Author](https://img.shields.io/badge/Author-Austin-orange)](https://t.me/FairyLtd)
[![github](https://img.shields.io/badge/Github-Austin.D-green)](https://github.com/AustinFairyland)
[![GitBook](https://img.shields.io/badge/GitBook-Austin.D-green)](https://interestingbooks.gitbook.io/)
[![Editor](https://img.shields.io/badge/Editor-PyCharm-yellow)](https://github.com/AustinFairyland)
[![Language](https://img.shields.io/badge/Language-Markdown-orange)](https://github.com/AustinFairyland)
[![Version](https://img.shields.io/badge/Version-Release-blue)](https://github.com/AustinFairyland)
[![Docs](https://img.shields.io/badge/Docs-Passing-brightgreen)](https://github.com/AustinFairyland)
[![Type](https://img.shields.io/badge/Type-Documents-blue)](https://github.com/AustinFairyland)
[![Wakatime](https://wakatime.com/badge/user/fa851759-c657-4b1e-8bcb-3ec3a693a2cd.svg)](https://wakatime.com/@fa851759-c657-4b1e-8bcb-3ec3a693a2cd)
[![Sign](https://img.shields.io/badge/%E7%AD%89%E6%88%91%E4%BB%A3%E7%A0%81%E7%BC%96%E6%88%90-%E5%A8%B6%E4%BD%A0%E4%B8%BA%E5%A6%BB%E5%8F%AF%E5%A5%BD-red)](https://github.com/AustinFairyland)

---

Development Environment

[![DevelopmentSystem](https://img.shields.io/badge/Development%20System-Win11Pro%20Workstations%2023H2%20Canary%20Channel-%230078D4?logo=windows11&logoColor=%230078D4)](https://www.microsoft.com/software-download/windows11)
[![VCS](https://img.shields.io/badge/VCS-GitHub-%23181717?logo=github&logoColor=%23181717)](https://github.com/AustinFairyland)
[![Anaconda](https://img.shields.io/badge/Anaconda-latest-%2344A833?logo=anaconda&logoColor=%2344A833)](https://www.anaconda.com/download#downloads)
[![Python](https://img.shields.io/badge/Python-3.9.13-%233776AB?logo=python&logoColor=%233776AB)](https://www.python.org/downloads/release/python-3913/)
[![Pip](https://img.shields.io/badge/PIP-23.2.1-%233775A9?logo=pypi&logoColor=%233775A9)](https://pypi.org/)
![MySQL](https://img.shields.io/badge/MySQL-8.0.33-%234479A1?logo=mysql&logoColor=%234479A1)
[![GO](https://img.shields.io/badge/Go-1.20.6-%2300ADD8?logo=go&logoColor=%2300ADD8)](https://go.dev/dl/)
![NodeJS](https://img.shields.io/badge/Node-18.18.0-%23339933?logo=nodedotjs&logoColor=%23339933)
![Npm](https://img.shields.io/badge/Npm-10.1.0-%23CB3837?logo=npm&logoColor=%23CB3837)
![Pnpm](https://img.shields.io/badge/Pnpm-8.7.6-%23F69220?logo=pnpm&logoColor=%23F69220)
![Yarn](https://img.shields.io/badge/Yarn-1.22.19-%232C8EBB?logo=yarn&logoColor=%232C8EBB)
![Maven](https://img.shields.io/badge/Maven-3.9.1-%23C71A36?logo=apachemaven&logoColor=%23C71A36)
![Perl](https://img.shields.io/badge/Perl-8.3.0-%2339457E?logo=perl&logoColor=%2339457E)
[![jetbrains](https://img.shields.io/badge/Jetbrains-2023-%2347f38a?logo=jetbrains&logoColor=%2347f38a)](https://www.jetbrains.com/)
![Git](https://img.shields.io/badge/Git-2.42.0-%23F05032?logo=git&logoColor=%23F05032)
![Chrome](https://img.shields.io/badge/Chrome-119_dev-%234285F4?logo=googlechrome&logoColor=%234285F4)
![AdaptingWindows](https://img.shields.io/badge/Adapting%20OS-Windows-%230078D4?logo=windows&logoColor=%230078D4)
![AdaptingLinux](https://img.shields.io/badge/Adapting%20OS-Linux-%23FCC624?logo=linux&logoColor=%23FCC624)
![AdaptingMac](https://img.shields.io/badge/Adapting%20OS-Mac-%23ffffff?logo=apple&logoColor=%23ffffff)
![Deployment](https://img.shields.io/badge/Deployment-Local-%2351BB7B?logo=local&logoColor=%2351BB7B)
[![Deployment](https://img.shields.io/badge/Deployment-Docker-%232496ED?logo=docker&logoColor=%232496ED)](https://www.docker.com/)
[![Deployment](https://img.shields.io/badge/Deployment-Kubernetes-%23326CE5?logo=kubernetes&logoColor=%23326CE5)](https://kubernetes.io/)
[![Package](https://img.shields.io/badge/Package-requirements.txt-%2302A8EF?logo=packer&logoColor=%2302A8EF)](requirements.txt)

---

[English](README.md) | [简体中文]()

# Quick Start

```shell
pip install PyFairyland
```

# Document

Tips: Wait fill up

# Further Information

Tips: Wait fill up

# Getting Support

Tips: Wait fill up

# Contributors

Tips: Wait fill up

# License

The `PyFairyland` module was written by Austin. Personal maintained.

`PyFairyland` is released under the AGPLv3+ license.

See the file LICENSE for more details.

---

[@HomePage](https://fairy.host) ·
[@Github](https://github.com/AustinFairyland) ·
[@TelegramGroup]()

